"""Setup file for FileOrganizer package."""

from setuptools import setup, find_packages

# Read requirements from requirements.txt
with open("requirements.txt", encoding="utf-8") as f:
    requirements = [line.strip() for line in f if line.strip()]

setup(
    name="OrganiserPro",
    version="0.1.0",  # This will be overridden by setuptools_scm
    packages=find_packages(where="."),
    python_requires=">=3.8,<3.13",
    install_requires=requirements,
    entry_points={
        "console_scripts": [
            "OrganiserPro=OrganiserPro.cli:main",
        ],
    },
    # Include package data files specified in MANIFEST.in
    include_package_data=True,
    # Metadata for PyPI
    author="Amber Boudreau",
    author_email="your.email@example.com",
    description="A powerful file organization tool",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/yourusername/OrganiserPro",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: End Users/Desktop",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    # Use setuptools_scm for versioning
    use_scm_version={
        "write_to": "OrganiserPro/_version.py",
        "write_to_template": """# coding: utf-8
# file generated by setuptools_scm
# don't change, don't track in version control
__version__ = version = '{version}'
__version_tuple__ = version_tuple = {version_tuple}
""",
    },
    setup_requires=["setuptools_scm"],
)
